pyLBM.Simulation
================

.. currentmodule:: pyLBM

.. autoclass:: Simulation

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Simulation.boundary_condition
         Simulation.equilibrium
         Simulation.f2m
         Simulation.initialization
         Simulation.m2f
         Simulation.one_time_step
         Simulation.relaxation
         Simulation.source_term
         Simulation.time_info
         Simulation.transport



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Simulation.F
         Simulation.F_halo
         Simulation.m
         Simulation.m_halo

